@@ -10,25 +10,25 @@ import cx_Oracle
 
 # TNS = cx_Oracle.makedsn("127.0.0.1", '1521',"orcl")
 # TNS = 127.0.0.1:1521/orcl
-TNS = "LOCALORCL"
+TNS = "RC_50.67ORCL"
 
 pool = PooledDB(cx_Oracle,
-                user="zhangzx",
-                password="Pwdasc123",
+                user="e_channel",
+                password="gN6Qrmjf7#R9G",
                 dsn=TNS,
                 mincached=5,
                 maxcached=20,
                 blocking=True,
-                test_idle = True,
+                test_idle=True,
                 maxconnections=50,
-                idle_check_time=60
+                idle_check_time=30
                 )
 
 
 def test_fun(conn, sql, params=[]):
     try:
         cus = conn.cursor()
-        print("testTimeout-sql"+sql)
+        # print("testTimeout-sql"+sql)
         print("testTimeout222-params=%s,现在的连接数=%s" % (str(params), pool._connections))
         result_db = cus.execute(sql, params)
         result = result_db.fetchall()
@@ -76,7 +76,7 @@ def start_check():
 
 
 def start_thread():
-    for i in range(100):
+    for i in range(60):
         Thread(target=start_check).start()
     time.sleep(20)
     print("testTimeout-%s现在的连接数%s_现在缓存的连接数%s" %
@@ -85,11 +85,6 @@ def start_thread():
     Timer(20, start_thread).start()
 
 
-if __name__ == '__main__':
-    for i in range(3):
-        threading.Thread(target=start_thread).start()
-
-
 class Dispacher(threading.Thread):
     def __init__(self, fun, *args, **kwargs):
         threading.Thread.__init__(self)
@@ -115,3 +110,10 @@ class Dispacher(threading.Thread):
         except Exception as e:
             print(e)
             self.error = sys.exc_info()
+
+
+if __name__ == '__main__':
+    time.sleep(35)
+    for i in range(3):
+        threading.Thread(target=start_thread).start()
+        time.sleep(30)
\ No newline at end of file
