@@ -144,6 +144,7 @@ import threading
 from threading import Condition, Timer
 import time
 from DBUtils import PooledDB as Pool_db
+import logging
 
 __version__ = '1.0'
 
@@ -165,7 +166,7 @@ class PooledDB(Pool_db.PooledDB):
             maxusage=None, setsession=None, reset=True,
             failures=None, ping=1, test_on_borrow=False, test_idle=True,
             validation_sql=None, idle_check_time=60, validate_timeout=1, max_wait_time=5,
-            *args, **kwargs):
+            logger=None, *args, **kwargs):
         """Set up the DB-API 2 connection pool.
 
         creator: either an arbitrary function returning new DB-API 2
@@ -220,6 +221,7 @@ class PooledDB(Pool_db.PooledDB):
             function or the connection constructor of the DB-API 2 module
 
         """
+        self._logger = logger if logger else logging.getLogger(__name__)
         try:
             threadsafety = creator.threadsafety
         except AttributeError:
@@ -293,17 +295,36 @@ class PooledDB(Pool_db.PooledDB):
         :param time_out:
         :return:
         """
-        if time_out:
-            self._lock.acquire()
-            try:
-                while len(self._idle_cache) > self._mincached:
-                    self._idle_cache.pop().close()  # 后进先出
-                    # self._connections -=1
-                self._lock.notify()
-            finally:
-                self._lock.release()
-            t = Timer(time_out, self.start_check_idle, [time_out])
-            t.start()
+        if not time_out:
+            return False
+
+        # self._lock.acquire()
+        try:
+            check_size = 0 if self._mincached <= 0 else self._mincached
+            while len(self._idle_cache) > check_size:
+                self._idle_cache.pop().close()  # 后进先出
+                # self._connections -=1
+            # self._lock.notify()
+            loop_times = len(self._idle_cache)
+            while loop_times > 0:
+                loop_times -= 1
+                con = None
+                try:  # first try to get it from the idle cache
+                    con = self._idle_cache.pop(0)
+                    flag = self._validate_connection(con, False)
+                    if flag:
+                        self._idle_cache.append(con)
+                except IndexError:  # else get a fresh connection
+                    break
+                finally:
+                    if not flag and con:
+                        self.close_conn(con, False)
+            return True
+        except Exception as e:
+            self._logger.error("check idle conn error:%s" % e)
+            return False
+        t = Timer(time_out, self.start_check_idle, [time_out])
+        t.start()
 
     def connection(self, shareable=True):
         # self._lock.acquire()
@@ -321,7 +342,7 @@ class PooledDB(Pool_db.PooledDB):
                     raise Pool_db.PooledDBError(error)
             else:
                 conn = self.new_connection(shareable)
-                # conn = super().connection(shareable)
+                # conn = super(PooledDB, self).connection(shareable)
             # self._lock.notify()
         except Exception as e:
             raise Pool_db.InvalidConnection(e)
@@ -406,10 +427,9 @@ class PooledDB(Pool_db.PooledDB):
                 self._lock.release()
         return con
 
-    def close_conn(self, conn):
+    def close_conn(self, conn, re_count_on_error=True):
         if not conn:
             return False
-        self._lock.acquire()
         try:
             conn.cancel()
             try:
@@ -417,14 +437,16 @@ class PooledDB(Pool_db.PooledDB):
             except:
                 pass
             conn.close()
-            if self._connections:
+            if re_count_on_error and self._connections:
+                self._lock.acquire()
                 self._connections -= 1
-            self._lock.notify()
+                # self._lock.notify()
+                self._lock.release()
         finally:
-            self._lock.release()
+            pass
         return True
 
-    def _validate_connection(self, conn, sql=None):
+    def _validate_connection(self, conn, sql=None, re_count_on_error=True):
         """
         校验连接是否可用 不可用时移除连接池
         :param conn:
@@ -440,17 +462,19 @@ class PooledDB(Pool_db.PooledDB):
                 if c.result:
                     return True
                 c.stop()
-                self.close_conn(conn)
+                # close connection when timeout
+                self.close_conn(conn, re_count_on_error)
             else:
                 res = exec_sql(conn=conn, sql=sql, params=[])
                 return True
         except Exception as e:
-            print("_validate_connection-error:", e)
+            self._logger.error("validate connection error:%s" % e)
 
         return False
 
 
 def exec_sql(conn, sql, params=()):
+    cus = None
     try:
         cus = conn.cursor()
         result_db = cus.execute(sql, params)
